@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: A Dancer2 plugin for creating routes from a Swagger2 spec
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.003_001'; # TRIAL VERSION
 
 use Dancer2 ':syntax';
 use Dancer2::Plugin;
@@ -25,6 +25,10 @@ register swagger2 => sub {
     my $controller_factory =
          $args{controller_factory} || \&_default_controller_factory;
     my $url = $args{url} or die "argument 'url' missing";
+    my $create_options_route =
+        exists $args{create_options_route}   ? !!$args{create_options_route}
+      : exists $conf->{create_options_route} ? !!$conf->{create_options_route}
+      :                                        '';
     my $validate_spec =
         exists $args{validate_spec}   ? !!$args{validate_spec}
       : exists $conf->{validate_spec} ? !!$conf->{validate_spec}
@@ -65,7 +69,23 @@ register swagger2 => sub {
         # '/path/{argument}' -> '/path/:argument'
         $dancer2_path =~ s/\{([^{}]+?)\}/:$1/g;
 
-        while ( my ( $http_method => $method_spec ) = each %$path_spec ) {
+        my @http_methods = sort keys %$path_spec;
+
+        if ($create_options_route) {
+            my $allow_methods = join ', ' => 'OPTIONS', map uc, @http_methods;
+            $dsl->options(
+                $dancer2_path => sub {
+                    $dsl->headers(
+                        Allow => $allow_methods,    # RFC 2616 HTTP/1.1
+                        'Access-Control-Allow-Methods' => $allow_methods, # CORS
+                        'Access-Control-Max-Age'       => 60 * 60 * 24,
+                    );
+                },
+            );
+        }
+
+        for my $http_method (@http_methods) {
+            my $method_spec = $path_spec->{ $http_method };
             my $coderef = $controller_factory->(
                 $method_spec, $http_method, $path, $dsl, $conf, \%args
             ) or next;
@@ -301,7 +321,7 @@ Dancer2::Plugin::Swagger2 - A Dancer2 plugin for creating routes from a Swagger2
 
 =head1 VERSION
 
-version 0.003
+version 0.003_001
 
 =head1 SYNOPSIS
 
@@ -313,7 +333,7 @@ C<example/my_app.pl>:
     use Dancer2::Plugin::Swagger2;
     use Path::Tiny;
 
-    swagger2( url => path(__FILE__)->parent->child('swagger2.yaml') );
+    swagger2( url => path(__FILE__)->sibling('swagger2.yaml') );
 
     sub my_controller {
         return "Hello World!\n";
@@ -370,6 +390,8 @@ Import routes from Swagger file. Named arguments:
 
 =item * C<controller_factory>: custom callback generator/finder that returns callbacks to routes
 
+=item * C<create_options_route>: autocreate additional route replying to OPTIONS requests based on Swagger data
+
 =item * C<validate_spec>: boolish value (default: true) telling if Swagger2 file shall be validated by official Swagger specification
 
 =item * C<validate_requests>: boolish value (default: same as C<validate_spec>) telling if HTTP requests shall be validated by loaded specification (needs C<validate_spec> to be true)
